@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
-$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.109';
+$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.110';
 # ABSTRACT: Generate valid CPAN::Changes Changelogs from git
 
 use v5.10.1;
@@ -171,14 +171,14 @@ sub after_build {
 
     return unless $self->copy_to_root;
 
-    my $build_file = $args->{build_root}->file($self->file_name);
+    my $build_file = $args->{build_root}->child($self->file_name);
 
-    my $root_file = $self->zilla->root->file($self->file_name);
+    my $root_file = $self->zilla->root->child($self->file_name);
     $self->log_debug("Copying changes file from $build_file to $root_file");
     if (!-e $build_file) {
         $self->logger->log_fatal("Where is the changelog?");
     }
-    $build_file->copy_to($root_file);
+    $build_file->copy($root_file);
 
     return;
 }
@@ -387,7 +387,7 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Generate valid CPAN::Chan
 
 =head1 VERSION
 
-version 0.109
+version 0.110
 
 =head1 SYNOPSIS
 
